@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     donghualin <donghualin@uniontech.com>
- *
- * Maintainer: donghualin <donghualin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "networkpluginhelper.h"
 #include "widgets/tipswidget.h"
@@ -66,11 +49,11 @@ using DBusAirplaneMode = com::deepin::daemon::AirplaneMode;
 
 NetworkPluginHelper::NetworkPluginHelper(NetworkDialog *networkDialog, QObject *parent)
     : QObject(parent)
-    , m_pluginState(PluginState::Unknow)
     , m_tipsWidget(new TipsWidget(nullptr))
     , m_switchWire(true)
     , m_networkDialog(networkDialog)
 {
+    qDBusRegisterMetaType<NMVariantMapMap>();
     initUi();
     initConnection();
 }
@@ -101,14 +84,9 @@ void NetworkPluginHelper::initConnection()
     });
 }
 
-void NetworkPluginHelper::updatePluginState()
-{
-    m_pluginState = DeviceStatusHandler::pluginState();
-}
-
 PluginState NetworkPluginHelper::getPluginState()
 {
-    return m_pluginState;
+    return DeviceStatusHandler::pluginState();
 }
 
 QList<QPair<QString, QStringList>> NetworkPluginHelper::ipTipsMessage(const DeviceType &devType)
@@ -138,7 +116,7 @@ QList<QPair<QString, QStringList>> NetworkPluginHelper::ipTipsMessage(const Devi
 
 void NetworkPluginHelper::updateTooltips()
 {
-    switch (m_pluginState) {
+    switch (getPluginState()) {
     case PluginState::Connected: {
         QList<QPair<QString, QStringList>> textList;
         textList << ipTipsMessage(DeviceType::Wireless) << ipTipsMessage(DeviceType::Wired);
@@ -419,7 +397,6 @@ QWidget *NetworkPluginHelper::itemTips()
 
 void NetworkPluginHelper::onUpdatePlugView()
 {
-    updatePluginState();
     updateTooltips();
     emit viewUpdate();
 }
@@ -477,27 +454,27 @@ bool NetworkPluginHelper::needSetPassword(AccessPoints *accessPoint) const
             break;
         }
     }
+
     // 如果连这个连接的设备都找不到，则无需设置密码
     if (!wirelessDevice)
         return false;
 
     // 查找该热点对应的连接的UUID
-    QString uuid;
-    QList<WirelessConnection *> conns = wirelessDevice->items();
-    for (WirelessConnection *con : conns) {
-        if (con->accessPoints() != accessPoint)
+    NetworkManager::Connection::Ptr connection;
+    NetworkManager::WirelessDevice::Ptr device(new NetworkManager::WirelessDevice(wirelessDevice->path()));
+    NetworkManager::Connection::List connectionlist = device->availableConnections();
+    for (NetworkManager::Connection::Ptr conn : connectionlist) {
+        NetworkManager::WirelessSetting::Ptr wSetting = conn->settings()->setting(NetworkManager::Setting::SettingType::Wireless).staticCast<NetworkManager::WirelessSetting>();
+        if (wSetting.isNull())
             continue;
 
-        uuid = con->connection()->uuid();
+        if (wSetting->ssid() != accessPoint->ssid())
+            continue;
+
+        connection = conn;
         break;
     }
 
-    // 如果没有找到对应的UUID连接，说明是新的连接，则此时需要设置密码
-    if (uuid.isEmpty())
-        return true;
-
-    // 查找该连接uuid对应的连接
-    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(uuid);
     if (connection.isNull())
         return true;
 
