@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     donghualin <donghualin@uniontech.com>
- *
- * Maintainer: donghualin <donghualin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef NETWORKPLUGINHELPER_H
 #define NETWORKPLUGINHELPER_H
@@ -69,7 +52,6 @@ public:
     const QString contextMenu(bool hasSetting) const;
     QWidget *itemTips();
     PluginState getPluginState();
-    void updatePluginState();
     void updateTooltips(); // 更新提示的内容
 
 private:
@@ -92,8 +74,6 @@ private Q_SLOTS:
     void onAccessPointsAdded(QList<AccessPoints *> newAps);
 
 private:
-    PluginState m_pluginState;
-
     TipsWidget *m_tipsWidget;
     bool m_switchWire;
     QPixmap m_iconPixmap;
