@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2022 Deepin Technology Co., Ltd.
- *
- * Author:     liaohanqin <liaohanqin@uniontech.com>
- *
- * Maintainer: liaohanqin <liaohanqin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "secretagent.h"
 
@@ -127,6 +110,8 @@ void SecretAgent::CancelGetSecrets(const QDBusObjectPath &connection_path, const
         SecretsRequest request = m_calls.at(i);
         if (request.type == SecretsRequest::GetSecrets && callId == request.callId) {
             if (m_process == request.process) {
+                DEBUG_PRINT << "process finished (agent canceled)";
+                m_process->deleteLater();
                 m_process = nullptr;
             }
             sendError(SecretAgent::AgentCanceled, QStringLiteral("Agent canceled the password dialog"), request.message);
@@ -169,6 +154,8 @@ void SecretAgent::processNext()
 
 void SecretAgent::dialogFinished()
 {
+    if (!m_process) return;
+
     readProcessOutput();
 
     for (int i = 0; i < m_calls.size(); ++i) {
@@ -224,6 +211,8 @@ void SecretAgent::readProcessOutput()
                                 request.connection[request.setting_name] = result;
                                 sendSecrets(request.connection, request.message);
                             }
+                        } else {
+                            sendError(SecretAgent::UserCanceled, QStringLiteral("user canceled"), request.message);
                         }
 
                         break;
@@ -298,6 +287,11 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
             return true;
         }
 
+        if (!userRequested) {
+            sendError(SecretAgent::AgentCanceled, QStringLiteral("dss only support user quest"), request.message);
+            return true;
+        }
+
         m_process = new QProcess;
 
         connect(m_process, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &SecretAgent::dialogFinished);
