@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2022 Deepin Technology Co., Ltd.
- *
- * Author:     liaohanqin <liaohanqin@uniontech.com>
- *
- * Maintainer: liaohanqin <liaohanqin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef SECRETAGENT_H
 #define SECRETAGENT_H
@@ -108,6 +91,7 @@ private:
      */
     bool hasSecrets(const NMVariantMapMap &connection) const;
     void sendSecrets(const NMVariantMapMap &secrets, const QDBusMessage &message) const;
+    bool needConnectNetwork(const NMVariantMapMap &connectionMap) const;
 
     mutable QProcess *m_process = nullptr;
     QList<SecretsRequest> m_calls;
