@@ -80,7 +80,7 @@
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished"/>
+        <translation>Conectando</translation>
     </message>
     <message>
         <source>Disconnect</source>
@@ -380,7 +380,7 @@
     </message>
     <message>
         <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
-        <translation type="unfinished"/>
+        <translation>Habilitar el modo avión apagara la red inalámbrica, el punto de acceso personal y Bluetooth</translation>
     </message>
 </context>
 <context>
