@@ -1,23 +1,7 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     caixiangrong <caixiangrong@uniontech.com>
- *
- * Maintainer: caixiangrong <caixiangrong@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "thememanager.h"
 #include "utils.h"
 
@@ -140,7 +124,7 @@ QColor ThemeManager::backgroundColor()
         return QColor(0, 0, 0, alpha);
     case GreeterType:
     case LockType:
-        return QColor(235, 235, 235, alpha);
+        return QColor(235, 235, 235, static_cast<int>(0.05 * 255));
     default:
         return QColor(255, 255, 255, alpha);
     }
