@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     sbw <sbw@sbw.so>
- *
- * Maintainer: sbw <sbw@sbw.so>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "networkplugin.h"
 #include "networkpluginhelper.h"
@@ -223,10 +206,17 @@ void NetworkPlugin::showNetworkDialog(QWidget *widget) const
         parentWidget = w;
         w = qobject_cast<QWidget *>(w->parentWidget());
     }
+
     if (parentWidget) {
         Dock::Position pos = qApp->property(PROP_POSITION).value<Dock::Position>();
         QPoint p = widget->rect().center();
         QRect rect = parentWidget->rect();
+
+        // 任务栏隐藏时不改变网络面板的位置,避免网络面板同步隐藏后不方便操作网络
+        if (rect.height() <= 0 || rect.width() <= 0) {
+            return;
+        }
+
         switch (pos) {
         case Dock::Position::Top:
             p.ry() += rect.height() / 2;
