@@ -1,23 +1,6 @@
-/*
-* Copyright (C) 2021 ~ 2021 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* Maintainer: Zhang Qipeng <zhangqipeng@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "network_module.h"
 #include "networkpluginhelper.h"
@@ -41,6 +24,7 @@
 #include <NetworkManagerQt/Settings>
 #include <NetworkManagerQt/Connection>
 #include <NetworkManagerQt/WiredSetting>
+#include <NetworkManagerQt/WirelessSecuritySetting>
 
 #define NETWORK_KEY "network-item-key"
 
@@ -292,6 +276,25 @@ void NetworkModule::addFirstConnection(NetworkManager::WiredDevice *nmDevice)
     }
 }
 
+bool NetworkModule::needPopupNetworkDialog() const
+{
+    // 如果上一次没有保存密码信息则不弹窗
+    if (m_lastConnectionUuid.isEmpty())
+        return false;
+
+    NetworkManager::Connection::Ptr connection = NetworkManager::findConnectionByUuid(m_lastConnectionUuid);
+    if (connection.isNull())
+        return false;
+
+    // 如果当前连接的密码是按照用户保存的，就不弹出来
+    WirelessSecuritySetting::Ptr securitySetting = connection->settings()->setting(Setting::SettingType::WirelessSecurity).staticCast<WirelessSecuritySetting>();
+    if (securitySetting.isNull())
+        return true;
+
+    NetworkManager::Setting::SecretFlags passwordFlags = securitySetting->pskFlags();
+    return (passwordFlags.testFlag(Setting::None));
+}
+
 void NetworkModule::onDeviceStatusChanged(NetworkManager::Device::State newstate, NetworkManager::Device::State oldstate, NetworkManager::Device::StateChangeReason reason)
 {
     if (m_isLockModel) {
@@ -301,9 +304,11 @@ void NetworkModule::onDeviceStatusChanged(NetworkManager::Device::State newstate
     NetworkManager::ActiveConnection::Ptr conn = device->activeConnection();
     if (!conn.isNull()) {
         m_lastConnection = conn->id();
+        m_lastConnectionUuid = conn->uuid();
         m_lastState = newstate;
     } else if (m_lastState != oldstate || m_lastConnection.isEmpty()) {
         m_lastConnection.clear();
+        m_lastConnectionUuid.clear();
         return;
     }
     switch (newstate) {
@@ -390,8 +395,10 @@ void NetworkModule::onDeviceStatusChanged(NetworkManager::Device::State newstate
                     break;
                 case Device::Type::Wifi:
                     NotificationManager::NetworkNotify(NotificationManager::WirelessConnectionFailed, m_lastConnection);
-                    emit signalShowNetworkDialog();
-                    m_networkDialog->setConnectWireless(device->uni(), m_lastConnection);
+                    if (needPopupNetworkDialog()) {
+                        emit signalShowNetworkDialog();
+                        m_networkDialog->setConnectWireless(device->uni(), m_lastConnection);
+                    }
                     break;
                 default:
                     break;
@@ -406,8 +413,11 @@ void NetworkModule::onDeviceStatusChanged(NetworkManager::Device::State newstate
             break;
         case Device::StateChangeReason::NoSecretsReason:
             NotificationManager::NetworkNotify(NotificationManager::NoSecrets, m_lastConnection);
-            emit signalShowNetworkDialog();
-            m_networkDialog->setConnectWireless(device->uni(), m_lastConnection);
+            if (needPopupNetworkDialog()) {
+                // 不是仅当前用户，就弹窗
+                emit signalShowNetworkDialog();
+                m_networkDialog->setConnectWireless(device->uni(), m_lastConnection);
+            }
             break;
         case Device::StateChangeReason::SsidNotFound:
             NotificationManager::NetworkNotify(NotificationManager::SsidNotFound, m_lastConnection);
