@@ -170,15 +170,15 @@
     </message>
     <message>
         <source>Wired Network %1</source>
-        <translation>Rede via Cabo %1</translation>
+        <translation>Rede Cabeada %1</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation>Rede sem fio</translation>
+        <translation>Rede Wi-Fi</translation>
     </message>
     <message>
         <source>Wireless Network %1</source>
-        <translation>Rede sem fio %1</translation>
+        <translation>Rede Wi-Fi %1</translation>
     </message>
 </context>
 <context>
