@@ -1,23 +1,6 @@
-/*
- * Copyright (C) 2011 ~ 2021 Deepin Technology Co., Ltd.
- *
- * Author:     donghualin <donghualin@uniontech.com>
- *
- * Maintainer: donghualin <donghualin@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #ifndef WIRELESSDEVICE_H
 #define WIRELESSDEVICE_H
@@ -52,6 +35,7 @@ public:
     QList<WirelessConnection *> items() const;                      // 无线网络连接列表
     AccessPoints *activeAccessPoints() const;                       // 当前活动的无线连接
     bool hotspotEnabled() const;                                    // 是否开启热点
+    void disconnectNetwork();
 
 Q_SIGNALS:
     void networkAdded(QList<AccessPoints *>);                       // wlan新增网络
@@ -113,6 +97,7 @@ public:
 Q_SIGNALS:
     void strengthChanged(const int) const;                          // 当前信号强度变化
     void connectionStatusChanged(ConnectionStatus);
+    void securedChanged(bool);
 
 protected:
     void updateAccessPoints(const QJsonObject &json);
